/// @file ilmsens_error.h
/// @brief Ilmsens error code definitions
///
/// The error codes defined in this file are used in various
/// Ilmsens APIs as return values.
///
/// @author Ralf Herrmann <ralf.herrmann@ilmsens.com>

#ifndef ILMSENS_ERROR_H
#define ILMSENS_ERROR_H

/**   
  * @defgroup ilmsens_errors Ilmsens Error Codes
  * @brief Ilmsens error codes provided as return values.
  * @{
  */  

/** Common error codes. */
enum ilmsens_error 
{
  /** No error. */
  ILMSENS_SUCCESS = 0, 

  /** Invalid parameter. */
  ILMSENS_ERROR_INVALID_PARAM = -1,
  
  /** Invalid state (e.g. on reading data, when no measurement is running). */
  ILMSENS_ERROR_STATE = -2,
  
  /** Ressource is busy. */
  ILMSENS_ERROR_BUSY = -3,
  
  /** Access denied. */
  ILMSENS_ERROR_ACCESS = -4,
  
  /** Input/Output error (e.g. transmission error or device disconnected). */
  ILMSENS_ERROR_IO = -5,

  /** Ressource allocation failed. */
  ILMSENS_ERROR_NO_MEMORY = -6,
  
  /** Not enough data, try again later (e.g. when a non-blocking operation would need to block the caller). */
  ILMSENS_ERROR_AGAIN = -7,
  
  /** Timeout expired. */
  ILMSENS_ERROR_TIMEOUT = -8,
  
  /** Operation not supported. */
  ILMSENS_ERROR_NOT_SUPPORTED = -9,

  /** Unspecified error. */
  ILMSENS_ERROR_UNKNOWN = -99
};

/** @} ilmsens_errors */


#endif // ILMSENS_ERROR_H
